@@ -51,6 +51,7 @@ sub new {
                 last_position => 0,
                 tag => '',
                 fmt => '',
+                lang => 'en',
                };
     foreach my $k (keys %$self) {
         if (defined $args{$k}) {
@@ -58,7 +59,7 @@ sub new {
         }
         delete $args{$k};
     }
-    die "Extra arguments passed %args" if %args;
+    die "Extra arguments passed :" . join(" ", %args) if %args;
     die "Missing type for <$self->{string}>" unless $self->{type};
     unless ($self->{fmt} eq 'ltx' or $self->{fmt} eq 'html') {
         die "Missing format $self->{fmt} for <$self->{string}>"
@@ -82,6 +83,16 @@ sub string {
     shift->{string};
 }
 
+=head2 lang
+
+The language code.
+
+=cut
+
+sub lang {
+    shift->{lang};
+}
+
 =head2 append($element)
 
 Append the provided string to the self's one and update the
@@ -124,7 +135,11 @@ sub stringify {
             return $string;
         }
         elsif ($self->is_html) {
-            return $self->escape_all_html($string);
+            $string =  $self->escape_all_html($string);
+            if ($self->lang eq 'fr') {
+                $string = $self->_html_french_punctuation($string);
+            }
+            return $string;
         }
         else {
             die "Not reached";
@@ -331,6 +346,46 @@ sub _ltx_replace_slash {
     return $string;
 }
 
+# https://unicode.org/udhr/n/notes_fra.html
+# espace fine insécable 	; 		espace justifiante
+# espace fine insécable 	! 		espace justifiante
+# espace fine insécable 	? 		espace justifiante
+
+# espace mots insécable 	: 		espace justifiante
+# espace mots insécable 	» 		espace justifiante
+
+# espace justifiante    	« 		espace mots insécable
+
+# espace justifiante 		tiret 	espace justifiante
+# pas de blanc 				, 		espace justifiante
+# pas de blanc 				. 		espace justifiante
+# espace justifiante 	( 	pas de blanc
+# espace justifiante 	[ 	pas de blanc
+# pas de blanc 	) 	espace justifiante
+# pas de blanc 	] 	espace justifiante
+
+
+sub _html_french_punctuation {
+    my ($self, $string) = @_;
+
+    # here we could use \x{202f}, but seems buggy, plus on readers is
+    # unclear how it will rendered. However, keep them separate for now
+
+    # optional space, punct, and then either space or end of line
+    $string =~ s/[\x{20}\x{a0}]*([;!?])(?=[\x{20}])/\x{a0}$1/gs;
+    $string =~ s/[\x{20}\x{a0}]*([;!?])$/\x{a0}$1/gms;
+
+    # ditto
+    $string =~ s/[\x{20}\x{a0}]*([:»])(?=[\x{20}])/\x{a0}$1/gs;
+    $string =~ s/[\x{20}\x{a0}]*([:»])$/\x{a0}$1/gms;
+
+    # easy: always add
+    $string =~ s/«[\x{20}\x{a0}]*/«\x{a0}/gs;
+    $string =~ s/\x{a0}/&#160;/g; # make them visible
+    return $string;
+}
+
+
 =head2 escape_all_html($string)
 
 HTML escape
