@@ -64,6 +64,8 @@ They return nothing, but nevertheless the Output module won't complain.
 
 =item attachments
 
+=item language_code
+
 =back
 
 =cut
@@ -81,5 +83,8 @@ sub attachments {
     return;
 }
 
+sub language_code {
+    return 'en';
+}
 
 1;
